FiniteRelation

Trait FiniteRelation 

pub trait FiniteRelation {
    // Required method
    fn len(&self) -> usize;

    // Provided method
    fn is_empty(&self) -> bool { ... }
}
Shared trait for finite relations. A finite relation that can report the number of stored tuples.

Required Methods

fn len(&self) -> usize

Returns the number of stored tuples in the relation.

Provided Methods

fn is_empty(&self) -> bool

Returns true when the relation contains no tuples.

Implementors